@@ -9,12 +9,14 @@ class CA:
     Auth: Final[str] = "aut"
 
     Code: Final[str] = "cd"
+    Count: Final[str] = "cnt"
 
     Data: Final[str] = "dt"
     DescriptionFormatted: Final[str] = "desf"
     DescriptionId: Final[str] = "desid"
     DescriptionPlain: Final[str] = "desp"
 
+    List: Final[str] = "lt"
     Login: Final[str] = "lgn"
 
     Name: Final[str] = "na"
@@ -30,4 +32,6 @@ class CA:
 
     UserId: Final[str] = "uid"
 
+    Word: Final[str] = "w"
+
     ___Error___: Final[str] = "err"
